@@ -8,21 +8,41 @@ SetuptoolsEngineConfig = {
     'wheel': ''
 }
 
-def init(_method, **_kwargs):
+def verify(_method, **_kwargs) -> bool:
+    force: bool = _kwargs.get('force', False)
+    if force: # If the force flag is set, the engine will be verified regardless of the packages installed
+        return True
+    
+    missing_packages = []
+    for package in ['toml', 'build', 'twine', 'setuptools']:
+        try:
+            __import__(package)
+        except ImportError:
+            missing_packages.append(package)
+
+    if missing_packages:
+        print('The following packages are required to use the Setuptools engine:')
+        for package in missing_packages:
+            print(f' - {package}')
+        return False
+    
+    return True
+
+def init(_method, **_kwargs) -> bool:
     edit_config()
     create_template_app()
     set_default_scripts()
-    create_toml()
+    create_files()
     return False
 
-def version(_method, **_kwargs):
+def version(_method, **_kwargs) -> bool:
     _method(**_kwargs)
     toml_file = load_toml()
     toml_file['project']['version'] = Config.get('version')
     save_toml(toml_file)
     return False
 
-def edit_config():
+def edit_config() -> None:
     Config.set('src_dir', sanitize_string_for_file(Config.get('project_name')))
     SetuptoolsEngineConfig['username'] = '__token__'
     SetuptoolsEngineConfig['password'] = 'pypi-<api-key>'
@@ -30,7 +50,7 @@ def edit_config():
     Config.set('twine', SetuptoolsEngineConfig)
     Config.save()
 
-def create_template_app():
+def create_template_app() -> None:
     os.makedirs(Config.get('src_dir'), exist_ok=True)
     with open(f'{Config.get('src_dir')}/app.py', 'w') as f:
         f.write('import os\n\n')
@@ -40,7 +60,7 @@ def create_template_app():
         f.write('if __name__ == "__main__":\n')
         f.write('    app()')
 
-def set_default_scripts():
+def set_default_scripts() -> None:
     default_scripts = {
         'start': f'py -m %src_dir%.app',
         'build': f'ppm-builtin-setuptools-build',
@@ -53,25 +73,7 @@ def set_default_scripts():
     Config.set('scripts', default_scripts)
     Config.save()
 
-# Setuptools Engine built-in cli commands
-# Allows for shorthand commands to be used in the cli
-_publish_command = 'del /S /Q %dist_dir%\\* && python -m build && twine upload -u %twine.username% -p %twine.password% -r pypi %dist_dir%/*'
-def _build():
-    os.system(Config.parse(f'ppm version inc -t && python -m build', Config._value_config))
-def _install():
-    os.system(Config.parse(f'pip install %dist_dir%/%twine.wheel%-%version%-py3-none-any.whl --force-reinstall', Config._value_config))
-def _uninstall():
-    os.system(Config.parse(f'pip uninstall %dist_dir%/%twine.wheel%-%version%-py3-none-any.whl', Config._value_config))
-def _publish():
-    os.system(Config.parse(f'del /S /Q %dist_dir%\\* && python -m build && twine upload -u %twine.username% -p %twine.password% -r pypi %dist_dir%/*', Config._value_config))
-def _publish_patch():
-    os.system(Config.parse(f'ppm version inc -p 1 && {_publish_command}', Config._value_config))
-def _publish_minor():
-    os.system(Config.parse(f'ppm version inc -m 1 && {_publish_command}', Config._value_config))
-def _publish_major():
-    os.system(Config.parse(f'ppm version inc -M 1 && {_publish_command}', Config._value_config))
-
-def create_toml():
+def create_files() -> None:
     toml_config = {
         'build-system': {
             'requires': ['setuptools', 'wheel'],
@@ -80,12 +82,12 @@ def create_toml():
 
         'project': {
             'name': sanitize_string_for_module(Config.get('project_name')),
-            'version': Config.get('version'),
+            'version': Config.get('version', '0.0.0'),
             'description': 'A Python package.',
             'authors': [],
             'readme': 'README.md',
             'keywords': [],
-            'dynamic': ['dependencies', 'optional-dependencies']
+            'dynamic': ['dependencies']
         },
         
         'tool': {
@@ -93,11 +95,6 @@ def create_toml():
                 'dynamic': {
                     'dependencies': {
                         'file': ['requirements.txt']
-                    },
-                    'optional-dependencies': {
-                        'dev': {
-                            'file': ['requirements-dev.txt']
-                        }
                     }
                 }
             }
@@ -105,11 +102,34 @@ def create_toml():
     }
     with open('pyproject.toml', 'w') as f:
         toml.dump(toml_config, f)
-
-def load_toml():
+    with open('LICENSE.txt', 'w') as f:
+        pass
+    with open('README.md', 'w') as f:
+        pass
+    
+def load_toml() -> dict:
     with open('pyproject.toml', 'r') as f:
         return toml.load(f)
     
-def save_toml(toml_config):
+def save_toml(toml_config) -> None:
     with open('pyproject.toml', 'w') as f:
-        toml.dump(toml_config, f)
\ No newline at end of file
+        toml.dump(toml_config, f)
+
+# Setuptools Engine built-in cli commands
+# Allows for shorthand commands to be used in the cli
+_publish_command = 'del /S /Q %dist_dir%\\* && python -m build && twine upload -u %twine.username% -p %twine.password% -r pypi %dist_dir%/*'
+VENV = f'venv\\Scripts\\activate'
+def _build():
+    os.system(Config.parse(f'{VENV} && ppm version inc -t && python -m build', Config._value_config))
+def _install():
+    os.system(Config.parse(f'{VENV} && pip install %dist_dir%/%twine.wheel%-%version%-py3-none-any.whl --force-reinstall', Config._value_config))
+def _uninstall():
+    os.system(Config.parse(f'{VENV} && pip uninstall %dist_dir%/%twine.wheel%-%version%-py3-none-any.whl', Config._value_config))
+def _publish():
+    os.system(Config.parse(f'{VENV} && IF EXIST %dist_dir% (del /S /Q %dist_dir%\*) && python -m build && twine upload -u %twine.username% -p %twine.password% -r pypi %dist_dir%/*', Config._value_config))
+def _publish_patch():
+    os.system(Config.parse(f'{VENV} && ppm version inc -p 1 && {_publish_command}', Config._value_config))
+def _publish_minor():
+    os.system(Config.parse(f'{VENV} && ppm version inc -m 1 && {_publish_command}', Config._value_config))
+def _publish_major():
+    os.system(Config.parse(f'{VENV} && ppm version inc -M 1 && {_publish_command}', Config._value_config))
\ No newline at end of file
